import { promises as fsPromises } from 'https://deno.land/std/node/fs.ts'
import { join } from 'https://deno.land/std/node/path.ts'
import { cwd } from 'https://deno.land/std/node/process.ts'
import Errlop from 'https://unpkg.com/errlop@^4.1.0/edition-deno/index.ts'
import { json, file } from './index.ts'
export * from './index.ts'

/**
 * Verify that the package directory declares a valid ECMAScript module file
 * @param packageRootDirectory the root path of the package directory to validate, defaults to the current working directory
 * @rejects if otherwise
 */
export async function local(
	packageRootDirectory: string = cwd()
): Promise<true> {
	let path = packageRootDirectory
	try {
		const data = JSON.parse(
			await fsPromises.readFile(
				join(packageRootDirectory, 'package.json'),
				'utf8'
			)
		)
		await json(data)
		path = join(packageRootDirectory, data.module)
		const content = await fsPromises.readFile(path, 'utf8')
		return await file(content)
	} catch (err) {
		return Promise.reject(new Errlop(`${path} is not a valid module`, err))
	}
}
